"""Default reserved words that should not be anonymized by sensitive word anonymization."""
#   Copyright 2018 Intentionet
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

# These are important tokens in network device configs and should not be modified by keyword anonymization
default_reserved_words = {
    '3des',
    '3des-cbc',
    '3des-sha1',
    '802.3ad',
    'aaa',
    'aaa-profile',
    'aaa-server',
    'aaa-user',
    'absolute-timeout',
    'accept',
    'accept-data',
    'accept-dialin',
    'accept-lifetime',
    'accept-own',
    'accept-register',
    'accept-rp',
    'accepted-prefix-limit',
    'access',
    'access-class',
    'access-group',
    'access-list',
    'access-log',
    'access-map',
    'access-profile',
    'accounting',
    'accounting-list',
    'accounting-port',
    'accounting-server-group',
    'accounting-threshold',
    'acct-port',
    'acfe',
    'ack',
    'acl',
    'acl-policy',
    'acllog',
    'action',
    'action-type',
    'activate',
    'activate-service-whitelist',
    'activation-character',
    'active',
    'active-server-group',
    'add',
    'add-path',
    'add-vlan',
    'additional-paths',
    'additive',
    'address',
    'address-book',
    'address-family',
    'address-hiding',
    'address-mask',
    'address-pool',
    'address-pools',
    'address-range',
    'address-set',
    'address-table',
    'addrgroup',
    'adjacency',
    'adjacency-check',
    'adjacency-stale-timer',
    'adjmgr',
    'admin',
    'admin-dist',
    'admin-distance',
    'admin-state',
    'admin-vdc',
    'administrative-weight',
    'admission',
    'admission-control',
    'adp',
    'advertise',
    'advertise-external',
    'advertise-inactive',
    'advertise-interval',
    'advertise-peer-as',
    'advertisement-interval',
    'aes',
    'aes-128-cbc',
    'aes-128-cmac-96',
    'aes-192-cbc',
    'aes-256-cbc',
    'aes128',
    'aes128-sha1',
    'aes192',
    'aes256',
    'aes256-sha1',
    'aesa',
    'af-group',
    'af11',
    'af12',
    'af13',
    'af21',
    'af22',
    'af23',
    'af31',
    'af32',
    'af33',
    'af41',
    'af42',
    'af43',
    'affinity',
    'affinity-map',
    'afs',
    'age',
    'aggregate',
    'aggregate-address',
    'aggregated-ether-options',
    'aggressive',
    'aging',
    'ah',
    'ahp',
    'airgroup',
    'airgroupservice',
    'ais-shut',
    'alarm',
    'alarm-report',
    'alert-group',
    'alerts',
    'alg',
    'alg-based-cac',
    'algorithm',
    'alias',
    'aliases',
    'all',
    'all-alarms',
    'all-of-router',
    'allocate',
    'allow',
    'allow-connections',
    'allow-default',
    'allow-fail-through',
    'allow-nopassword-remote-login',
    'allow-self-ping',
    'allow-v4mapped-packets',
    'allowas-in',
    'allowed',
    'alternate-address',
    'always',
    'always-compare-med',
    'always-on',
    'always-on-vpn',
    'always-send',
    'am-disable',
    'am-scan-profile',
    'amon',
    'and',
    'antenna',
    'any',
    'any-ipv4',
    'any-ipv6',
    'any-remote-host',
    'any-service',
    'any4',
    'any6',
    'anyconnect',
    'anyconnect-essentials',
    'aol',
    'ap',
    'ap-blacklist-time',
    'ap-classification-rule',
    'ap-crash-transfer',
    'ap-group',
    'ap-lacp-striping-ip',
    'ap-name',
    'ap-rule-matching',
    'ap-system-profile',
    'api',
    'app',
    'appcategory',
    'appletalk',
    'application',
    'application-protocol',
    'application-set',
    'application-tracking',
    'applications',
    'apply',
    'apply-macro',
    'apply-path',
    'aqm-register-fnf',
    'archive',
    'archive-length',
    'archive-size',
    'area',
    'area-password',
    'area-range',
    'arm-profile',
    'arm-rf-domain-profile',
    'arp',
    'arp-resp',
    'as',
    'as-number',
    'as-override',
    'as-path',
    'as-path-expand',
    'as-path-prepend',
    'as-path-set',
    'as-set',
    'asa',
    'ascii-authentication',
    'ascii-text',
    'asdm',
    'asdm-buffer-size',
    'asdot-notation',
    'asn',
    'assembler',
    'assignment',
    'assoc-retransmit',
    'associate',
    'association',
    'asymmetric',
    'async',
    'async-bootp',
    'asynchronous',
    'atm',
    'attached',
    'attribute',
    'attribute-download',
    'attribute-map',
    'attribute-names',
    'attribute-set',
    'attributes',
    'audit',
    'auth',
    'auth-failure-blacklist-time',
    'auth-port',
    'auth-proxy',
    'auth-server',
    'authenticate',
    'authentication',
    'authentication-algorithm',
    'authentication-dot1x',
    'authentication-key',
    'authentication-key-chain',
    'authentication-key-chains',
    'authentication-mac',
    'authentication-method',
    'authentication-order',
    'authentication-port',
    'authentication-retries',
    'authentication-server',
    'authentication-server-group',
    'authentication-type',
    'authoritative',
    'authorization',
    'authorization-required',
    'authorization-server-group',
    'authtype',
    'auto',
    'auto-cert-allow-all',
    'auto-cert-allowed-addrs',
    'auto-cert-prov',
    'auto-cost',
    'auto-export',
    'auto-import',
    'auto-local-addr',
    'auto-negotiation',
    'auto-recovery',
    'auto-rp',
    'auto-shutdown-new-neighbors',
    'auto-snapshot',
    'auto-summary',
    'auto-sync',
    'auto-tunnel',
    'auto-update',
    'auto-upgrade',
    'autohang',
    'autohangup',
    'autonomous-system',
    'autorecovery',
    'autoroute',
    'autorp',
    'autoselect',
    'autostate',
    'aux',
    'back-up',
    'backbonefast',
    'background-routes-enable',
    'backoff-time',
    'backup',
    'backup-router',
    'backupcrf',
    'band-steering',
    'bandwidth',
    'bandwidth-contract',
    'bandwidth-percentage',
    'banner',
    'bash',
    'basic',
    'batfish_role_declarations',
    'bcmc-optimization',
    'bcn-rpt-req-profile',
    'beacon',
    'bestpath',
    'beyond-scope',
    'bfd',
    'bfd-enable',
    'bfd-liveness-detection',
    'bgp',
    'bgp-community',
    'bgp-policy',
    'bidir-enable',
    'bidir-offer-interval',
    'bidir-offer-limit',
    'bidir-rp-limit',
    'biff',
    'bind',
    'bind-interface',
    'bittorrent',
    'bittorrent-application',
    'bkup-lms-ip',
    'blackhole',
    'blacklist',
    'blacklist-time',
    'block',
    'bloggerd',
    'bmp',
    'bonddevs',
    'bonding',
    'bondmiimon',
    'bondmode',
    'bool',
    'boot',
    'boot-end-marker',
    'boot-server',
    'boot-start-marker',
    'bootfile',
    'bootp',
    'bootp-relay',
    'bootpc',
    'bootps',
    'border',
    'border-router',
    'both',
    'boundary',
    'bpdufilter',
    'bpduguard',
    'bridge',
    'bridge-domain',
    'bridge-domains',
    'bridge-group',
    'bridge-priority',
    'broadcast',
    'broadcast-address',
    'broadcast-client',
    'broadcast-filter',
    'bsd-client',
    'bsd-username',
    'bsr-border',
    'bsr-candidate',
    'buckets',
    'buffer-size',
    'buffered',
    'buffers',
    'building configuration',
    'bundle',
    'burst-size',
    'ca',
    'cable-downstream',
    'cable-range',
    'cable-upstream',
    'cablelength',
    'cache',
    'cache-timeout',
    'call',
    'call-block',
    'call-forward',
    'call-home',
    'call-manager-fallback',
    'caller-id',
    'callhome',
    'cam-acl',
    'cam-profile',
    'capability',
    'captive',
    'captive-portal-cert',
    'capture',
    'card',
    'card-trap-inh',
    'carrier-delay',
    'cas-custom',
    'case',
    'categories',
    'ccc',
    'ccm',
    'ccm-group',
    'ccm-manager',
    'cdp',
    'cdp-url',
    'cef',
    'centralized-licensing-enable',
    'certificate',
    'certificates',
    'cfs',
    'cgmp',
    'channel',
    'channel-group',
    'channel-protocol',
    'channelized',
    'chap',
    'chargen',
    'chassis',
    'chassis-id',
    'chat-script',
    'check',
    'cipc',
    'cir',
    'circuit-type',
    'cisp',
    'citrix-ica',
    'class',
    'class-map',
    'class-of-service',
    'classless',
    'cleanup',
    'clear',
    'cli',
    'client',
    'client-group',
    'client-identifier',
    'client-list-name',
    'client-name',
    'client-to-client',
    'clients',
    'clns',
    'clock',
    'clock-period',
    'closed',
    'cluster',
    'cluster-id',
    'cmd',
    'cmts',
    'cns',
    'coap',
    'codec',
    'codes',
    'collect',
    'collect-stats',
    'color',
    'color2',
    'comm-list',
    'commander-address',
    'commands',
    'commit',
    'common',
    'community',
    'community-list',
    'community-map',
    'community-set',
    'compare-routerid',
    'compatible',
    'compress-configuration-files',
    'compression',
    'con',
    'condition',
    'conf-level-incr',
    'confdconfig',
    'confederation',
    'config',
    'config-commands',
    'config-management',
    'config-register',
    'configuration',
    'configure',
    'configversion',
    'conflict-policy',
    'conform-action',
    'congestion-control',
    'conn',
    'conn-holddown',
    'connect-retry',
    'connect-source',
    'connected',
    'connection',
    'connection-reuse',
    'connection-type',
    'connections',
    'connections-limit',
    'console',
    'contact',
    'contact-email-addr',
    'contact-name',
    'context',
    'contract-id',
    'control-apps-use-mgmt-port',
    'control-plane',
    'control-plane-security',
    'control-word',
    'controller',
    'controller-ip',
    'conversion-error',
    'cookie',
    'copp',
    'cops',
    'copy',
    'cos',
    'cos-mapping',
    'cos-next-hop-map',
    'cos-queue-group',
    'cost',
    'count',
    'counter',
    'counters',
    'country',
    'country-code',
    'cpd',
    'cptone',
    'cpu-share',
    'crashinfo',
    'crc',
    'credentials',
    'credibility-protocol-preference',
    'critical',
    'crl',
    'crypto',
    'crypto-local',
    'cryptochecksum',
    'cryptographic-algorithm',
    'cs1',
    'cs2',
    'cs3',
    'cs4',
    'cs5',
    'cs6',
    'cs7',
    'csd',
    'csnp-interval',
    'ctiqbe',
    'ctl-file',
    'cts',
    'current configuration',
    'custom',
    'customer-id',
    'cvspserver',
    'cvx',
    'cwr',
    'd20-ggrp-default',
    'd30-ggrp-default',
    'daemon',
    'dampen',
    'dampen-igp-metric',
    'dampening',
    'damping',
    'data-privacy',
    'database',
    'databits',
    'daytime',
    'dbl',
    'dcb',
    'dcb-buffer-threshold',
    'dcb-policy',
    'dcbx',
    'dce-mode',
    'ddos-protection',
    'deactivate',
    'dead-interval',
    'dead-peer-detection',
    'deadtime',
    'debug',
    'debug-trace',
    'debugging',
    'decap-group',
    'default-action',
    'default-address-selection',
    'default-cost',
    'default-destination',
    'default-domain',
    'default-gateway',
    'default-group-policy',
    'default-guest-role',
    'default-gw',
    'default-information',
    'default-information-originate',
    'default-inspection-traffic',
    'default-lsa',
    'default-max-frame-size',
    'default-metric',
    'default-network',
    'default-originate',
    'default-policy',
    'default-role',
    'default-router',
    'default-taskgroup',
    'default-tos-qos10',
    'default-value',
    'defaults',
    'definition',
    'del',
    'delay',
    'delay-start',
    'delete',
    'delete-dynamic-learn',
    'delimiter',
    'demand-circuit',
    'dense-mode',
    'deny',
    'deny-all',
    'deny-inter-user-traffic',
    'depi',
    'depi-class',
    'depi-tunnel',
    'deploy',
    'derivation-rules',
    'des',
    'des-cbc',
    'des-sha1',
    'description',
    'desirable',
    'despassword',
    'dest-ip',
    'destination',
    'destination-address',
    'destination-host-unknown',
    'destination-ip',
    'destination-network-unknown',
    'destination-pattern',
    'destination-port',
    'destination-port-except',
    'destination-prefix-list',
    'destination-profile',
    'destination-slot',
    'destination-unreachable',
    'destination-vrf',
    'detail',
    'detect-adhoc-network',
    'detect-ap-flood',
    'detect-ap-impersonation',
    'detect-bad-wep',
    'detect-beacon-wrong-channel',
    'detect-chopchop-attack',
    'detect-client-flood',
    'detect-cts-rate-anomaly',
    'detect-eap-rate-anomaly',
    'detect-hotspotter',
    'detect-ht-40mhz-intolerance',
    'detect-ht-greenfield',
    'detect-invalid-address-combination',
    'detect-invalid-mac-oui',
    'detect-malformed-association-request',
    'detect-malformed-auth-frame',
    'detect-malformed-htie',
    'detect-malformed-large-duration',
    'detect-misconfigured-ap',
    'detect-overflow-eapol-key',
    'detect-overflow-ie',
    'detect-rate-anomalies',
    'detect-rts-rate-anomaly',
    'detect-tkip-replay-attack',
    'detect-valid-ssid-misuse',
    'detect-wireless-bridge',
    'detect-wireless-hosted-network',
    'deterministic-med',
    'dev',
    'device',
    'device-sensor',
    'df',
    'df-bit',
    'dfa-regex',
    'dfs',
    'dh-group',
    'dh-group14',
    'dh-group15',
    'dh-group16',
    'dh-group17',
    'dh-group18',
    'dh-group19',
    'dh-group2',
    'dh-group20',
    'dh-group21',
    'dh-group22',
    'dh-group23',
    'dh-group24',
    'dh-group25',
    'dh-group26',
    'dh-group5',
    'dhcp',
    'dhcp-giaddr',
    'dhcp-relay',
    'dhcpd',
    'dhcprelay',
    'diagnostic',
    'diagnostic-signature',
    'dial-control-mib',
    'dial-peer',
    'dial-string',
    'dialer',
    'dialer-group',
    'dialer-list',
    'dialplan-pattern',
    'dialplan-profile',
    'direct',
    'direct-inward-dial',
    'directed-broadcast',
    'directed-request',
    'disable',
    'disable-4byte-as',
    'disable-advertisement',
    'disable-connected-check',
    'disable-peer-as-check',
    'discard',
    'discard-route',
    'discovered-ap-cnt',
    'discovery',
    'discriminator',
    'dispute',
    'distance',
    'distribute',
    'distribute-list',
    'distribution',
    'dm-fallback',
    'dns',
    'dns-domain',
    'dns-guard',
    'dns-server',
    'dns1',
    'dns2',
    'dnsix',
    'do',
    'docsis-enable',
    'docsis-group',
    'docsis-policy',
    'docsis-version',
    'docsis30-enable',
    'domain',
    'domain-id',
    'domain-list',
    'domain-lookup',
    'domain-name',
    'domain-search',
    'done',
    'dont-capability-negotiate',
    'dos-profile',
    'dot11',
    'dot11a-radio-profile',
    'dot11g-radio-profile',
    'dot11k-profile',
    'dot11r-profile',
    'dot1p-priority',
    'dot1q-tunnel',
    'dot1x-default-role',
    'dot1x-enable',
    'dot1x-server-group',
    'downlink',
    'downstream',
    'downstream-start-threshold',
    'dpg',
    'dr-priority',
    'drop',
    'ds-hello-interval',
    'ds-max-burst',
    'ds0-group',
    'dsa-signatures',
    'dscp',
    'dscp-value',
    'dsg',
    'dsl',
    'dsp',
    'dspfarm',
    'dsrwait',
    'dss',
    'dst-nat',
    'dstopts',
    'dsu',
    'dtmf-relay',
    'dual-active',
    'dual-mode-default-vlan',
    'dummy',
    'dump-on-panic',
    'duplex',
    'duplicate-message',
    'duration',
    'dvmrp',
    'dynamic',
    'dynamic-access-policy-record',
    'dynamic-capability',
    'dynamic-extended',
    'dynamic-map',
    'dynamic-mcast-optimization',
    'dynamic-mcast-optimization-thresh',
    'e164',
    'e164-pattern-map',
    'eap-passthrough',
    'eapol-rate-opt',
    'early-offer',
    'ebgp',
    'ebgp-multihop',
    'ece',
    'echo',
    'echo-cancel',
    'echo-reply',
    'echo-request',
    'ecmp',
    'ecmp-group',
    'ecn',
    'edca-parameters-profile',
    'edge',
    'ef',
    'egp',
    'egress',
    'egress-interface-selection',
    'eibgp',
    'eigrp',
    'eklogin',
    'ekshell',
    'else',
    'elseif',
    'email',
    'email-addr',
    'email-contact',
    'emergencies',
    'empty',
    'emptypath',
    'enable',
    'enable-acl-cam-sharing',
    'enable-acl-counter',
    'enable-authentication',
    'enable-qos-statistics',
    'enable-welcome-page',
    'enabled',
    'encapsulation',
    'encr',
    'encrypted',
    'encrypted-password',
    'encryption',
    'encryption-algorithm',
    'end',
    'end-class-map',
    'end-policy',
    'end-policy-map',
    'end-set',
    'endif',
    'enet-link-profile',
    'enforce-dhcp',
    'enforce-first-as',
    'enforce-rule',
    'enforced',
    'engine',
    'enhanced-hash-key',
    'enrollment',
    'environment',
    'environment-monitor',
    'eof',
    'eq',
    'errdisable',
    'error',
    'error-enable',
    'error-passthru',
    'error-rate-threshold',
    'error-recovery',
    'errors',
    'erspan-id',
    'escape-character',
    'esm',
    'esp',
    'esp-3des',
    'esp-aes',
    'esp-des',
    'esp-gcm',
    'esp-gmac',
    'esp-group',
    'esp-md5-hmac',
    'esp-null',
    'esp-seal',
    'esp-sha-hmac',
    'esp-sha256-hmac',
    'essid',
    'establish-tunnels',
    'established',
    'eth',
    'ether-options',
    'etherchannel',
    'ethernet',
    'ethernet-services',
    'ethernet-switching',
    'ethernet-switching-options',
    'etype',
    'evaluate',
    'event',
    'event-handler',
    'event-history',
    'event-options',
    'event-thresholds-profile',
    'events',
    'exact',
    'exceed-action',
    'except',
    'exception',
    'exception-slave',
    'exclude',
    'excluded-address',
    'exec',
    'exec-timeout',
    'execute',
    'exit',
    'exit-address-family',
    'exit-peer-policy',
    'exit-peer-session',
    'exit-vrf',
    'exp',
    'expanded',
    'expect',
    'explicit-null',
    'explicit-priority',
    'export',
    'export-protocol',
    'export-rib',
    'exporter',
    'exporter-map',
    'expression',
    'extcomm-list',
    'extcommunity',
    'extcommunity-list',
    'extend',
    'extended',
    'extended-counters',
    'extended-delay',
    'extensions',
    'external',
    'external-interface',
    'external-lsa',
    'external-preference',
    'external-router-id',
    'fabric',
    'fabric-mode',
    'fabric-options',
    'fabricpath',
    'facility',
    'facility-alarm',
    'facility-override',
    'fail-filter',
    'fail-over',
    'failed',
    'failed-list',
    'failover',
    'fair-queue',
    'fall-over',
    'fallback',
    'fallback-dn',
    'false',
    'family',
    'fan',
    'fast-age',
    'fast-detect',
    'fast-external-fallover',
    'fast-flood',
    'fast-reroute',
    'fastether-options',
    'fax',
    'fax-relay',
    'fcoe',
    'fdl',
    'feature',
    'feature-set',
    'fex',
    'fex-fabric',
    'fiber-node',
    'fields',
    'file',
    'file-browsing',
    'file-entry',
    'file-size',
    'file-transfer',
    'filter',
    'filter-list',
    'fin',
    'finger',
    'firewall',
    'firewall-visibility',
    'firmware',
    'first-fragment',
    'flap-list',
    'flash',
    'flash-override',
    'flexible-vlan-tagging',
    'floating-conn',
    'flow',
    'flow-accounting',
    'flow-aggregation',
    'flow-cache',
    'flow-capture',
    'flow-control',
    'flow-export',
    'flow-sampler',
    'flow-sampler-map',
    'flow-sampling-mode',
    'flow-top-talkers',
    'flowcont',
    'flowcontrol',
    'flush-at-activation',
    'flush-r1-on-new-r0',
    'for',
    'force',
    'force-up',
    'forever',
    'format',
    'forward',
    'forward-digits',
    'forward-protocol',
    'forward-snooped-clients',
    'forwarder',
    'forwarding',
    'forwarding-class',
    'forwarding-options',
    'forwarding-table',
    'fpd',
    'fqdn',
    'fragment',
    'fragment-offset',
    'fragment-offset-except',
    'fragmentation-needed',
    'fragments',
    'frame-relay',
    'framing',
    'free-channel-index',
    'frequency',
    'fri',
    'from',
    'from-zone',
    'ft',
    'ftp',
    'ftp-data',
    'ftp-server',
    'full-duplex',
    'full-txt',
    'g709',
    'g729',
    'gatekeeper',
    'gateway',
    'gateway1',
    'gbps',
    'ge',
    'general-group-defaults',
    'general-profile',
    'generate',
    'gid',
    'gig-default',
    'gigether-options',
    'glbp',
    'global',
    'global-mtu',
    'global-port-security',
    'globalenforcepriv',
    'gopher',
    'graceful-restart',
    'gracetime',
    'grant',
    'gratuitous-arps',
    'gre',
    'green',
    'group',
    'group-alias',
    'group-ike-id',
    'group-list',
    'group-lock',
    'group-object',
    'group-policy',
    'group-range',
    'group-timeout',
    'group-url',
    'group1',
    'group14',
    'group2',
    'group5',
    'groups',
    'gt',
    'guaranteed',
    'guard',
    'guest-access-email',
    'guest-logon',
    'guest-mode',
    'gui',
    'guimenuname',
    'gw-type-prefix',
    'h225',
    'h323',
    'h323-gateway',
    'ha-policy',
    'half-closed',
    'half-duplex',
    'handover-trigger-profile',
    'hardware',
    'hardware-address',
    'hardware-count',
    'hash',
    'hash-algorithm',
    'hash-key',
    'header-compression',
    'header-passing',
    'heartbeat-interval',
    'heartbeat-time',
    'hello',
    'hello-authentication-key',
    'hello-authentication-type',
    'hello-interval',
    'hello-multiplier',
    'hello-padding',
    'hello-password',
    'helper-address',
    'helpers',
    'hidden',
    'hidden-shares',
    'hidekeys',
    'high',
    'high-availability',
    'high-resolution',
    'history',
    'hmac-md5-96',
    'hmac-sha-1',
    'hmac-sha-1-96',
    'hmac-sha1-96',
    'hold-queue',
    'hold-time',
    'homedir',
    'hop-by-hop',
    'hop-limit',
    'hoplimit',
    'hops-of-statistics-kept',
    'host',
    'host-association',
    'host-inbound-traffic',
    'host-info',
    'host-name',
    'host-proxy',
    'host-routing',
    'host-unknown',
    'host-unreachable',
    'hostname',
    'hotspot',
    'hpm',
    'hsrp',
    'ht-ssid-profile',
    'http',
    'http-commands',
    'https',
    'hunt',
    'hw-id',
    'hw-module',
    'hw-switch',
    'ibgp',
    'iccp',
    'icmp',
    'icmp-code',
    'icmp-echo',
    'icmp-error',
    'icmp-errors',
    'icmp-object',
    'icmp-type',
    'icmp6',
    'icmp6-code',
    'icmp6-type',
    'icmpv6',
    'id',
    'id-mismatch',
    'id-randomization',
    'ideal-coverage-index',
    'ident',
    'ident-reset',
    'identity',
    'idle',
    'idle-timeout',
    'idletimeout',
    'idp-cert',
    'ids',
    'ids-profile',
    'iec',
    'ietf-format',
    'if',
    'if-needed',
    'ifacl',
    'ifdescr',
    'ifindex',
    'ifmap',
    'ifmib',
    'ifname',
    'igmp',
    'igmp-snooping',
    'ignore',
    'ignore-l3-incompletes',
    'igp',
    'igp-cost',
    'igrp',
    'ike',
    'ike-esp-nat',
    'ike-group',
    'ike-policy',
    'ike-user-type',
    'ikev1',
    'ikev2',
    'ikev2-profile',
    'ikev2-reauth',
    'ilmi-keepalive',
    'imap',
    'imap4',
    'immediate',
    'immediately',
    'impersonation-profile',
    'implicit-user',
    'import',
    'import-policy',
    'import-rib',
    'inactive',
    'inactive:',
    'inactivity-timeout',
    'inactivity-timer',
    'inband',
    'inbound',
    'include-mp-next-hop',
    'include-stub',
    'incoming',
    'incomplete',
    'index',
    'indirect-next-hop',
    'indirect-next-hop-change-acknowledgements',
    'inet',
    'inet-mdt',
    'inet-mvpn',
    'inet-vpn',
    'inet6',
    'inet6-vpn',
    'infinity',
    'information',
    'information-reply',
    'information-request',
    'informational',
    'ingress',
    'inherit',
    'inheritance-disable',
    'init',
    'init-string',
    'init-tech-list',
    'initial-role',
    'initiate',
    'inner',
    'input',
    'input-list',
    'input-vlan-map',
    'inservice',
    'inside',
    'inspect',
    'install',
    'install-nexthop',
    'instance',
    'instance-type',
    'integer',
    'integrity',
    'inter',
    'interactive-commands',
    'interarea',
    'intercept',
    'interconnect-device',
    'interface',
    'interface-mode',
    'interface-routes',
    'interface-specific',
    'interface-switch',
    'interface-transmit-statistics',
    'interface-type',
    'interfaces',
    'internal',
    'internet',
    'internet-options',
    'interval',
    'interworking',
    'intra',
    'invalid-spi-recovery',
    'invalid-username-log',
    'invert',
    'invert-match',
    'ios-regex',
    'ip',
    'ip route table for vrf',
    'ip-address',
    'ip-flow-export-profile',
    'ip-options',
    'ipaddr',
    'ipaddress',
    'ipbroadcast',
    'ipc',
    'ipenacl',
    'iphc-format',
    'ipinip',
    'ipip',
    'ipmask',
    'ipsec',
    'ipsec-interfaces',
    'ipsec-isakmp',
    'ipsec-over-tcp',
    'ipsec-policy',
    'ipsec-proposal',
    'ipsec-udp',
    'ipsec-vpn',
    'ipsla',
    'iptables',
    'ipv4',
    'ipv4-l5',
    'ipv6',
    'ipv6-address-pool',
    'ipx',
    'irc',
    'irdp',
    'is',
    'is directly connected',
    'is variably subnetted',
    'is-fragment',
    'is-local',
    'is-type',
    'isakmp',
    'isdn',
    'isis',
    'isis-enhanced',
    'isis-metric',
    'isl',
    'iso',
    'isolate',
    'ispf',
    'issuer-name',
    'iuc',
    'join-group',
    'jumbo',
    'jumbomtu',
    'junos-aol',
    'junos-bgp',
    'junos-biff',
    'junos-bootpc',
    'junos-bootps',
    'junos-chargen',
    'junos-cifs',
    'junos-cvspserver',
    'junos-dhcp-client',
    'junos-dhcp-relay',
    'junos-dhcp-server',
    'junos-discard',
    'junos-dns-tcp',
    'junos-dns-udp',
    'junos-echo',
    'junos-finger',
    'junos-ftp',
    'junos-gnutella',
    'junos-gopher',
    'junos-gre',
    'junos-gtp',
    'junos-h323',
    'junos-host',
    'junos-http',
    'junos-http-ext',
    'junos-https',
    'junos-icmp-all',
    'junos-icmp-ping',
    'junos-icmp6-all',
    'junos-icmp6-dst-unreach-addr',
    'junos-icmp6-dst-unreach-admin',
    'junos-icmp6-dst-unreach-beyond',
    'junos-icmp6-dst-unreach-port',
    'junos-icmp6-dst-unreach-route',
    'junos-icmp6-echo-reply',
    'junos-icmp6-echo-request',
    'junos-icmp6-packet-to-big',
    'junos-icmp6-param-prob-header',
    'junos-icmp6-param-prob-nexthdr',
    'junos-icmp6-param-prob-option',
    'junos-icmp6-time-exceed-reassembly',
    'junos-icmp6-time-exceed-transit',
    'junos-ident',
    'junos-ike',
    'junos-ike-nat',
    'junos-imap',
    'junos-imaps',
    'junos-internet-locator-service',
    'junos-irc',
    'junos-l2tp',
    'junos-ldap',
    'junos-ldp-tcp',
    'junos-ldp-udp',
    'junos-lpr',
    'junos-mail',
    'junos-mgcp',
    'junos-mgcp-ca',
    'junos-mgcp-ua',
    'junos-ms-rpc',
    'junos-ms-rpc-any',
    'junos-ms-rpc-epm',
    'junos-ms-rpc-iis-com',
    'junos-ms-rpc-iis-com-1',
    'junos-ms-rpc-iis-com-adminbase',
    'junos-ms-rpc-msexchange',
    'junos-ms-rpc-msexchange-directory-nsp',
    'junos-ms-rpc-msexchange-directory-rfr',
    'junos-ms-rpc-msexchange-info-store',
    'junos-ms-rpc-tcp',
    'junos-ms-rpc-udp',
    'junos-ms-rpc-uuid-any-tcp',
    'junos-ms-rpc-uuid-any-udp',
    'junos-ms-rpc-wmic',
    'junos-ms-rpc-wmic-admin',
    'junos-ms-rpc-wmic-admin2',
    'junos-ms-rpc-wmic-mgmt',
    'junos-ms-rpc-wmic-webm-callresult',
    'junos-ms-rpc-wmic-webm-classobject',
    'junos-ms-rpc-wmic-webm-level1login',
    'junos-ms-rpc-wmic-webm-login-clientid',
    'junos-ms-rpc-wmic-webm-login-helper',
    'junos-ms-rpc-wmic-webm-objectsink',
    'junos-ms-rpc-wmic-webm-refreshing-services',
    'junos-ms-rpc-wmic-webm-remote-refresher',
    'junos-ms-rpc-wmic-webm-services',
    'junos-ms-rpc-wmic-webm-shutdown',
    'junos-ms-sql',
    'junos-msn',
    'junos-nbds',
    'junos-nbname',
    'junos-netbios-session',
    'junos-nfs',
    'junos-nfsd-tcp',
    'junos-nfsd-udp',
    'junos-nntp',
    'junos-ns-global',
    'junos-ns-global-pro',
    'junos-nsm',
    'junos-ntalk',
    'junos-ntp',
    'junos-ospf',
    'junos-pc-anywhere',
    'junos-persistent-nat',
    'junos-ping',
    'junos-pingv6',
    'junos-pop3',
    'junos-pptp',
    'junos-printer',
    'junos-r2cp',
    'junos-radacct',
    'junos-radius',
    'junos-realaudio',
    'junos-rip',
    'junos-routing-inbound',
    'junos-rsh',
    'junos-rtsp',
    'junos-sccp',
    'junos-sctp-any',
    'junos-sip',
    'junos-smb',
    'junos-smb-session',
    'junos-smtp',
    'junos-snmp-agentx',
    'junos-snpp',
    'junos-sql-monitor',
    'junos-sqlnet-v1',
    'junos-sqlnet-v2',
    'junos-ssh',
    'junos-stun',
    'junos-sun-rpc',
    'junos-sun-rpc-any',
    'junos-sun-rpc-any-tcp',
    'junos-sun-rpc-any-udp',
    'junos-sun-rpc-mountd',
    'junos-sun-rpc-mountd-tcp',
    'junos-sun-rpc-mountd-udp',
    'junos-sun-rpc-nfs',
    'junos-sun-rpc-nfs-access',
    'junos-sun-rpc-nfs-tcp',
    'junos-sun-rpc-nfs-udp',
    'junos-sun-rpc-nlockmgr',
    'junos-sun-rpc-nlockmgr-tcp',
    'junos-sun-rpc-nlockmgr-udp',
    'junos-sun-rpc-portmap',
    'junos-sun-rpc-portmap-tcp',
    'junos-sun-rpc-portmap-udp',
    'junos-sun-rpc-rquotad',
    'junos-sun-rpc-rquotad-tcp',
    'junos-sun-rpc-rquotad-udp',
    'junos-sun-rpc-ruserd',
    'junos-sun-rpc-ruserd-tcp',
    'junos-sun-rpc-ruserd-udp',
    'junos-sun-rpc-sadmind',
    'junos-sun-rpc-sadmind-tcp',
    'junos-sun-rpc-sadmind-udp',
    'junos-sun-rpc-sprayd',
    'junos-sun-rpc-sprayd-tcp',
    'junos-sun-rpc-sprayd-udp',
    'junos-sun-rpc-status',
    'junos-sun-rpc-status-tcp',
    'junos-sun-rpc-status-udp',
    'junos-sun-rpc-tcp',
    'junos-sun-rpc-udp',
    'junos-sun-rpc-walld',
    'junos-sun-rpc-walld-tcp',
    'junos-sun-rpc-walld-udp',
    'junos-sun-rpc-ypbind',
    'junos-sun-rpc-ypbind-tcp',
    'junos-sun-rpc-ypbind-udp',
    'junos-sun-rpc-ypserv',
    'junos-sun-rpc-ypserv-tcp',
    'junos-sun-rpc-ypserv-udp',
    'junos-syslog',
    'junos-tacacs',
    'junos-tacacs-ds',
    'junos-talk',
    'junos-tcp-any',
    'junos-telnet',
    'junos-tftp',
    'junos-udp-any',
    'junos-uucp',
    'junos-vdo-live',
    'junos-vnc',
    'junos-wais',
    'junos-who',
    'junos-whois',
    'junos-winframe',
    'junos-wxcontrol',
    'junos-x-windows',
    'junos-xnm-clear-text',
    'junos-xnm-ssl',
    'junos-ymsg',
    'kbps',
    'keep',
    'keepalive',
    'keepalive-enable',
    'keepout',
    'kerberos',
    'kerberos-sec',
    'kernel',
    'key',
    'key-chain',
    'key-exchange',
    'key-hash',
    'key-source',
    'key-string',
    'keypair',
    'keypath',
    'keyring',
    'keys',
    'keystore',
    'klogin',
    'kpasswd',
    'krb-prop',
    'krbupdate',
    'kron',
    'kshell',
    'l',
    'l2',
    'l2-filter',
    'l2-interface',
    'l2-src',
    'l2circuit',
    'l2protocol',
    'l2protocol-tunnel',
    'l2tp',
    'l2tp-class',
    'l2tpv3',
    'l2vpn',
    'l3-interface',
    'label',
    'label-switched-path',
    'labeled-unicast',
    'lacp',
    'lacp-timeout',
    'lag',
    'lan',
    'lane',
    'lapb',
    'last-as',
    'last-member-query-count',
    'last-member-query-interval',
    'last-member-query-response-time',
    'layer2-control',
    'lcd-menu',
    'ldap',
    'ldap-base-dn',
    'ldap-login',
    'ldap-login-dn',
    'ldap-naming-attribute',
    'ldap-scope',
    'ldaps',
    'ldp',
    'ldp-synchronization',
    'le',
    'learn-vlan-1p-priority',
    'lease',
    'length',
    'level',
    'level-1',
    'level-1-2',
    'level-2',
    'level-2-only',
    'license',
    'life',
    'lifetime',
    'lifetime-kilobytes',
    'lifetime-seconds',
    'limit',
    'limit-dn',
    'limit-resource',
    'line',
    'linecard',
    'linecard-group',
    'linecode',
    'link',
    'link-fail',
    'link-fault-signaling',
    'link-mode',
    'link-protection',
    'link-type',
    'linkdebounce',
    'list',
    'listen',
    'listen-port',
    'listener',
    'lldp',
    'lldp-med',
    'lms-ip',
    'lms-preemption',
    'lo',
    'load-balance',
    'load-balancing',
    'load-interval',
    'load-sharing',
    'local',
    'local-address',
    'local-as',
    'local-identity',
    'local-interface',
    'local-ip',
    'local-port',
    'local-preference',
    'local-v6-addr',
    'local-volatile',
    'locale',
    'localip',
    'location',
    'log',
    'log-adj-changes',
    'log-adjacency-changes',
    'log-enable',
    'log-input',
    'log-internal-sync',
    'log-neighbor-changes',
    'log-prefix',
    'log-updown',
    'logfile',
    'logging',
    'logical-systems',
    'login',
    'login-attempts',
    'login-authentication',
    'login-page',
    'loginsession',
    'logout-warning',
    'longer',
    'lookup',
    'loopback',
    'loopguard',
    'loops',
    'loss-priority',
    'lotusnotes',
    'low',
    'lpd',
    'lpts',
    'lre',
    'lrq',
    'lsp',
    'lsp-equal-cost',
    'lsp-gen-interval',
    'lsp-interval',
    'lsp-lifetime',
    'lsp-password',
    'lsp-refresh-interval',
    'lsping',
    'lt',
    'mac',
    'mac-address',
    'mac-address-table',
    'mac-default-role',
    'mac-learn',
    'mac-server-group',
    'machine-authentication',
    'macro',
    'mail-server',
    'main',
    'main-cpu',
    'maintenance',
    'management',
    'management-access',
    'management-only',
    'management-plane',
    'management-profile',
    'manager',
    'mangle',
    'map',
    'map-class',
    'map-group',
    'map-list',
    'mapped-port',
    'mapping',
    'martians',
    'mask',
    'mask-reply',
    'mask-request',
    'master',
    'master-only',
    'masterip',
    'match',
    'match-all',
    'match-any',
    'matches-any',
    'matches-every',
    'max-associations',
    'max-authentication-failures',
    'max-burst',
    'max-clients',
    'max-concat-burst',
    'max-conferences',
    'max-configuration-rollbacks',
    'max-configurations-on-flash',
    'max-connections',
    'max-dn',
    'max-ephones',
    'max-ifindex-per-module',
    'max-lsa',
    'max-lsp-lifetime',
    'max-metric',
    'max-rate',
    'max-route',
    'max-session-number',
    'max-sessions',
    'max-tx-power',
    'maxconnections',
    'maximum',
    'maximum-accepted-routes',
    'maximum-labels',
    'maximum-paths',
    'maximum-peers',
    'maximum-prefix',
    'maximum-routes',
    'maxpoll',
    'maxstartups',
    'maxsubs',
    'mbps',
    'mbssid',
    'mcast-boundary',
    'mcast-rate-opt',
    'md5',
    'mdix',
    'mdt',
    'med',
    'media',
    'media-termination',
    'media-type',
    'medium',
    'medium-high',
    'medium-low',
    'member',
    'members',
    'memory',
    'memory-size',
    'menu',
    'menuname',
    'mesh-cluster-profile',
    'mesh-group',
    'mesh-ht-ssid-profile',
    'mesh-radio-profile',
    'message-counter',
    'message-digest-key',
    'message-length',
    'message-level',
    'message-size',
    'metering',
    'method',
    'method-utilization',
    'metric',
    'metric-out',
    'metric-style',
    'metric-type',
    'metric2',
    'mfib',
    'mfib-mode',
    'mfwd',
    'mgcp',
    'mgcp-ca',
    'mgcp-pat',
    'mgcp-ua',
    'mgmt-auth',
    'mgmt-server',
    'mgmt-user',
    'mh',
    'mib',
    'microcode',
    'microsoft-ds',
    'midcall-signaling',
    'min-packet-size',
    'min-rate',
    'min-tx-power',
    'minimal',
    'minimum',
    'minimum-interval',
    'minimum-links',
    'minpoll',
    'mirror',
    'mlag',
    'mld',
    'mld-query',
    'mld-reduction',
    'mld-report',
    'mldv2',
    'mls',
    'mobile',
    'mobile-ip',
    'mobile-redirect',
    'mobileip-agent',
    'mobilip-mn',
    'mobility',
    'mode',
    'modem',
    'modulation-profile',
    'module-type',
    'mon',
    'monitor',
    'monitor-interface',
    'monitor-map',
    'monitor-session',
    'monitoring',
    'monitoring-basics',
    'mop',
    'motd',
    'mpls',
    'mpls-label',
    'mroute',
    'mroute-cache',
    'ms-rpc',
    'mschap',
    'mschapv2',
    'msdp',
    'msdp-peer',
    'msie-proxy',
    'msrpc',
    'mst',
    'mstp',
    'mta',
    'mtu',
    'mtu-discovery',
    'mtu-ignore',
    'multi-chassis',
    'multi-config',
    'multi-topology',
    'multicast',
    'multicast-boundary',
    'multicast-mac',
    'multicast-routing',
    'multicast-static-only',
    'multihop',
    'multilink',
    'multipath',
    'multiple-as',
    'multiplier',
    'multiservice-options',
    'mvpn',
    'mvr',
    'name',
    'name-lookup',
    'name-resolution',
    'name-server',
    'named-key',
    'nameif',
    'names',
    'nameserver',
    'namespace',
    'nat',
    'nat-control',
    'nat-transparency',
    'nat-traversal',
    'native',
    'native-vlan-id',
    'natpool',
    'nbar',
    'nd',
    'nd-na',
    'nd-ns',
    'nd-type',
    'negotiate',
    'negotiated',
    'negotiation',
    'neighbor',
    'neighbor-advertisement',
    'neighbor-discovery',
    'neighbor-down',
    'neighbor-filter',
    'neighbor-group',
    'neighbor-solicit',
    'neq',
    'nested',
    'net',
    'net-unreachable',
    'netbios-dgm',
    'netbios-ns',
    'netbios-ss',
    'netbios-ssn',
    'netconf',
    'netdestination',
    'netdestination6',
    'netexthdr',
    'netmask',
    'netservice',
    'network-clock',
    'network-clock-participate',
    'network-clock-select',
    'network-delay',
    'network-domain',
    'network-object',
    'network-summary-export',
    'network-unknown',
    'network-unreachable',
    'never',
    'new-model',
    'newinfo',
    'next',
    'next-header',
    'next-hop',
    'next-hop-self',
    'next-hop-third-party',
    'next-ip',
    'next-ip6',
    'next-server',
    'next-table',
    'nexthop',
    'nexthop-attribute',
    'nexthop-list',
    'nexthop-self',
    'nexthop1',
    'nexthop2',
    'nfsd',
    'nhop-only',
    'nhrp',
    'nls',
    'nmsp',
    'nntp',
    'no l4r_shim',
    'no-active-backbone',
    'no-adjacency-down-notification',
    'no-advertise',
    'no-anti-replay',
    'no-auto-negotiation',
    'no-client-reflect',
    'no-ecmp-fast-reroute',
    'no-export',
    'no-flow-control',
    'no-install',
    'no-ipv4-routing',
    'no-nat-traversal',
    'no-neighbor-down-notification',
    'no-neighbor-learn',
    'no-nexthop-change',
    'no-prepend',
    'no-readvertise',
    'no-redirects',
    'no-redistribution',
    'no-resolve',
    'no-retain',
    'no-rfc-1583',
    'no-summaries',
    'no-summary',
    'no-traps',
    'noauth',
    'node',
    'node-device',
    'node-group',
    'noe',
    'nohangup',
    'non-broadcast',
    'non-client-nrt',
    'non-deterministic-med',
    'non500-isakmp',
    'nonegotiate',
    'nonstop-routing',
    'nos',
    'not',
    'not-advertise',
    'notiffacility',
    'notification',
    'notification-timer',
    'notifications',
    'notifpriority',
    'notify',
    'notify-filter',
    'notifyaddressname',
    'notifyaddressservice',
    'notifyaddressstate',
    'notifyservicename',
    'notifyserviceprotocol',
    'notifyserviceraw',
    'nsf',
    'nsr',
    'nssa',
    'nssa-external',
    'ntalk',
    'ntp',
    'ntpaddress',
    'ntpaltaddress',
    'ntpsourceinterface',
    'null',
    'nv',
    'oam',
    'object',
    'object-group',
    'octet',
    'octetstring',
    'off',
    'offset',
    'on',
    'on-failure',
    'on-passive',
    'on-startup',
    'on-success',
    'one',
    'one-out-of',
    'open',
    'openflow',
    'openvpn',
    'operation',
    'opmode',
    'ops',
    'optical-monitor',
    'optimization-profile',
    'optimize',
    'optimized',
    'option',
    'options',
    'or',
    'origin',
    'origin-id',
    'originate',
    'originator-id',
    'orlonger',
    'ospf',
    'ospf-external-type-1',
    'ospf-external-type-2',
    'ospf-inter-area',
    'ospf-intra-area',
    'ospf-nssa-type-1',
    'ospf-nssa-type-2',
    'ospf3',
    'ospfv3',
    'other-access',
    'oui',
    'out-delay',
    'out-of-band',
    'outauthtype',
    'outbound-acl-check',
    'outer',
    'output',
    'output-list',
    'output-vlan-map',
    'outside',
    'overload',
    'overload-control',
    'override',
    'override-metric',
    'overrides',
    'owner',
    'p2p',
    'package',
    'packet',
    'packet-capture-defaults',
    'packet-length',
    'packet-length-except',
    'packet-too-big',
    'packetcable',
    'packetsize',
    'pager',
    'pan',
    'pan-options',
    'param',
    'parameter-problem',
    'parameters',
    'parent',
    'parity',
    'parser',
    'participate',
    'pass',
    'passive',
    'passive-interface',
    'passive-only',
    'passphrase',
    'passwd',
    'password',
    'password-policy',
    'password-storage',
    'pat-xlate',
    'path',
    'path-count',
    'path-echo',
    'path-jitter',
    'path-option',
    'path-retransmit',
    'path-selection',
    'pathcost',
    'paths',
    'paths-of-statistics-kept',
    'pathsize',
    'pause',
    'payload-protocol',
    'pcanywhere-data',
    'pcanywhere-status',
    'pcp',
    'pcp-value',
    'pd-route-injection',
    'peakdetect',
    'peer',
    'peer-address',
    'peer-as',
    'peer-config-check-bypass',
    'peer-gateway',
    'peer-group',
    'peer-id-validate',
    'peer-keepalive',
    'peer-link',
    'peer-policy',
    'peer-session',
    'peer-switch',
    'peer-to-peer',
    'peer-unit',
    'penalty-period',
    'per-packet',
    'per-unit-scheduler',
    'percent',
    'perfect-forward-secrecy',
    'periodic',
    'periodic-inventory',
    'periodic-refresh',
    'permanent',
    'permission',
    'permit',
    'permit-all',
    'permit-hostdown',
    'persistent',
    'persistent-nat',
    'pfc',
    'pfs',
    'pgm',
    'phone-contact',
    'phone-number',
    'phone-proxy',
    'phy',
    'physical-layer',
    'physical-port',
    'pickup',
    'pim',
    'pim-auto-rp',
    'pim-sparse',
    'ping',
    'pinning',
    'pki',
    'plat',
    'platform',
    'pm',
    'poap',
    'poe',
    'point-to-multipoint',
    'point-to-point',
    'police',
    'policer',
    'policies',
    'policy',
    'policy-list',
    'policy-map',
    'policy-map-input',
    'policy-map-output',
    'policy-options',
    'policy-statement',
    'poll-interval',
    'pool',
    'pop2',
    'pop3',
    'port',
    'port-channel',
    'port-channel-protocol',
    'port-mirror',
    'port-mirroring',
    'port-mode',
    'port-name',
    'port-object',
    'port-overloading',
    'port-overloading-factor',
    'port-priority',
    'port-profile',
    'port-randomization',
    'port-security',
    'port-type',
    'port-unreachable',
    'portfast',
    'portmode',
    'ports',
    'pos',
    'postrotuing',
    'power',
    'power-level',
    'power-mgr',
    'power-monitor',
    'poweroff',
    'ppm',
    'pptp',
    'prc-interval',
    'pre-equalization',
    'pre-shared-key',
    'pre-shared-keys',
    'pre-shared-secret',
    'precedence',
    'precision-timers',
    'predictor',
    'preempt',
    'prefer',
    'preference',
    'preferred',
    'preferred-path',
    'prefix',
    'prefix-export-limit',
    'prefix-length',
    'prefix-length-range',
    'prefix-limit',
    'prefix-list',
    'prefix-list-filter',
    'prefix-policy',
    'prefix-set',
    'prerotuing',
    'prf',
    'pri-group',
    'primary',
    'primary-port',
    'primary-priority',
    'printer',
    'priority',
    'priority-cost',
    'priority-flow-control',
    'priority-force',
    'priority-mapping',
    'priority-queue',
    'priv',
    'privacy',
    'private',
    'private-as',
    'private-key',
    'private-vlan',
    'privilege',
    'privilege-mode',
    'proactive',
    'probe',
    'process',
    'process-max-time',
    'processes',
    'profile',
    'progress_ind',
    'prompt',
    'propagate',
    'proposal',
    'proposal-set',
    'proposals',
    'proprietary',
    'protect',
    'protect-ssid',
    'protect-tunnel',
    'protect-valid-sta',
    'protection',
    'protocol',
    'protocol-http',
    'protocol-object',
    'protocol-violation',
    'protocols',
    'provider-tunnel',
    'provision',
    'provisioning-profile',
    'proxy-arp',
    'proxy-identity',
    'proxy-server',
    'pruning',
    'pseudo-ethernet',
    'pseudo-information',
    'pseudowire',
    'pseudowire-class',
    'psh',
    'ptp',
    'pubkey-chain',
    'public-key',
    'pvc',
    'q931',
    'qos',
    'qos-group',
    'qos-mapping',
    'qos-policy',
    'qos-policy-output',
    'qos-sc',
    'qualified-next-hop',
    'query-interval',
    'query-max-response-time',
    'query-only',
    'query-timeout',
    'queue',
    'queue-buffers',
    'queue-length',
    'queue-limit',
    'queue-monitor',
    'queue-set',
    'quit',
    'r2cp',
    'radacct',
    'radius',
    'radius-accounting',
    'radius-acct',
    'radius-common-pw',
    'radius-interim-accounting',
    'radius-options',
    'radius-server',
    'radprimacctsecret',
    'radprimsecret',
    'radsecacctsecret',
    'radsecsecret',
    'random',
    'random-detect',
    'random-detect-label',
    'range',
    'ras',
    'rate-limit',
    'rate-mode',
    'rate-thresholds-profile',
    'raw',
    'rbacl',
    'rc4-sha1',
    'rcmd',
    'rcp',
    'rcv-queue',
    'rd',
    'reachable-via',
    'react',
    'reaction',
    'read-only',
    'read-only-password',
    'read-write',
    'readvertise',
    'real',
    'real-time-config',
    'realaudio',
    'reauthentication',
    'receive',
    'receive-window',
    'reconnect-interval',
    'record',
    'record-entry',
    'red',
    'redirect',
    'redirect-fqdn',
    'redirect-list',
    'redirect-pause',
    'redirects',
    'redistribute',
    'redistribute-internal',
    'redistributed-prefixes',
    'redundancy',
    'redundancy-group',
    'redundant-ether-options',
    'redundant-parent',
    'reference-bandwidth',
    'reflect',
    'reflexive-list',
    'register-rate-limit',
    'register-source',
    'registered',
    'regulatory-domain-profile',
    'reject',
    'relay-agent-option',
    'reload',
    'reload-delay',
    'reload-type',
    'remark',
    'remote',
    'remote-access',
    'remote-as',
    'remote-id',
    'remote-ip',
    'remote-port',
    'remote-ports',
    'remote-server',
    'remote-span',
    'remoteaccesslist',
    'remove',
    'remove-private',
    'removed',
    'reoptimize',
    'replace-as',
    'reply-to',
    'req-trans-policy',
    'request',
    'request-data-size',
    'require-wpa',
    'resolution',
    'resolve',
    'resource',
    'resource-pool',
    'resources',
    'respond',
    'responder',
    'response',
    'restrict',
    'restricted',
    'retain',
    'retransmit',
    'retransmit-interval',
    'retransmit-timeout',
    'retries',
    'retry',
    'return',
    'reverse-access',
    'reverse-path',
    'reverse-route',
    'reverse-ssh',
    'reverse-telnet',
    'revertive',
    'revision',
    'revocation-check',
    'rewrite',
    'rf',
    'rf-channel',
    'rf-power',
    'rf-shutdown',
    'rf-switch',
    'rfc-3576-server',
    'rfc1583',
    'rfc1583compatibility',
    'rib',
    'rib-group',
    'rib-groups',
    'rib-has-route',
    'rib-metric-as-external',
    'rib-metric-as-internal',
    'ring',
    'rip',
    'ripng',
    'rkinit',
    'rlogin',
    'rmon',
    'robustness-variable',
    'rogue-ap-aware',
    'role',
    'root',
    'root-authentication',
    'rotary',
    'route',
    'route-cache',
    'route-distinguisher',
    'route-filter',
    'route-map',
    'route-only',
    'route-policy',
    'route-reflector-client',
    'route-source',
    'route-target',
    'route-type',
    'routed',
    'router',
    'router-advertisement',
    'router-alert',
    'router-discovery',
    'router-id',
    'router-interface',
    'router-lsa',
    'router-solicit',
    'router-solicitation',
    'routing',
    'routing-instance',
    'routing-instances',
    'routing-options',
    'rp',
    'rp-address',
    'rp-announce-filter',
    'rp-candidate',
    'rp-list',
    'rpc-program-number',
    'rpf-check',
    'rpf-vector',
    'rpm',
    'rrm-ie-profile',
    'rsa',
    'rsa-signatures',
    'rsakeypair',
    'rsh',
    'rst',
    'rstp',
    'rsvp',
    'rtcp-inactivity',
    'rtp',
    'rtp-port',
    'rtr',
    'rtr-adv',
    'rtsp',
    'rule',
    'rule-name',
    'rule-set',
    'run',
    'rx',
    'rx-cos-slot',
    'rxspeed',
    'sa-filter',
    'same-security-traffic',
    'sample',
    'sampler',
    'sampler-map',
    'samples-of-history-kept',
    'sampling',
    'sap',
    'sat',
    'satellite',
    'satellite-fabric-link',
    'saved-core-context',
    'saved-core-files',
    'scale-factor',
    'scan-time',
    'scanning',
    'sccp',
    'sched-type',
    'schedule',
    'scheduler',
    'scheme',
    'scope',
    'scp',
    'scramble',
    'screen',
    'script',
    'scripting',
    'scripts',
    'sctp',
    'sdm',
    'sdr',
    'sdrowner',
    'secondary',
    'secondary-dialtone',
    'secret',
    'secure-mac-address',
    'secureid-udp',
    'security',
    'security-association',
    'security-level',
    'security-zone',
    'securityv3',
    'select',
    'selective',
    'self',
    'send',
    'send-community',
    'send-community-ebgp',
    'send-extended-community-ebgp',
    'send-label',
    'send-lifetime',
    'send-rp-announce',
    'send-rp-discovery',
    'sender',
    'sensor',
    'sequence',
    'sequence-nums',
    'serial-number',
    'serve',
    'serve-only',
    'server',
    'server-arp',
    'server-group',
    'server-private',
    'server-type',
    'serverfarm',
    'service',
    'service-class',
    'service-filter',
    'service-list',
    'service-module',
    'service-object',
    'service-policy',
    'service-queue',
    'service-type',
    'services',
    'session',
    'session-authorization',
    'session-disconnect-warning',
    'session-group',
    'session-id',
    'session-limit',
    'session-open-mode',
    'session-protection',
    'session-timeout',
    'set',
    'set-color',
    'set-overload-bit',
    'setup',
    'severity',
    'sflow',
    'sftp',
    'sg-expiry-timer',
    'sha',
    'sha-256',
    'sha-384',
    'sha1',
    'sha2-256-128',
    'sha256',
    'sha384',
    'sha512',
    'shapassword',
    'shape',
    'shared-ike-id',
    'shared-secondary-secret',
    'shared-secret',
    'shelfname',
    'shell',
    'short',
    'short-txt',
    'shortcuts',
    'shortstring',
    'show',
    'shutdown',
    'signal',
    'signaling',
    'signalled-bandwidth',
    'signalled-name',
    'signalling',
    'signature',
    'signature-matching-profile',
    'signature-profile',
    'signing',
    'simple',
    'single-connection',
    'single-router-mode',
    'single-topology',
    'sip',
    'sip-disconnect',
    'sip-invite',
    'sip-midcall-req-timeout',
    'sip-profiles',
    'sip-provisional-media',
    'sip-server',
    'sip-ua',
    'sip_media',
    'sips',
    'site-id',
    'site-to-site',
    'sla',
    'slot',
    'slot-table-cos',
    'small-hello',
    'smart-relay',
    'smp_affinity',
    'smtp',
    'smtp-server',
    'snmp',
    'snmp-authfail',
    'snmp-server',
    'snmp-trap',
    'snmpgetclient',
    'snmpgetcommunity',
    'snmpsourceinterface',
    'snmptrap',
    'snmptrapclient',
    'snmptrapcommunity',
    'snooping',
    'snp',
    'snpp',
    'snr-max',
    'snr-min',
    'sntp',
    'socks',
    'soft-preemption',
    'soft-reconfiguration',
    'software',
    'sonet',
    'sonet-options',
    'sort-by',
    'source',
    'source-address',
    'source-address-filter',
    'source-identity',
    'source-interface',
    'source-ip-address',
    'source-nat',
    'source-port',
    'source-prefix-list',
    'source-protocol',
    'source-quench',
    'source-route',
    'span',
    'spanning-tree',
    'sparse-dense-mode',
    'sparse-mode',
    'sparse-mode-ssm',
    'spd',
    'spe',
    'spectrum',
    'spectrum-load-balancing',
    'spectrum-monitoring',
    'speed',
    'speed-duplex',
    'spf-interval',
    'spf-options',
    'split-tunnel-network-list',
    'split-tunnel-policy',
    'spt-threshold',
    'sqlnet',
    'sqlnet-v2',
    'src-nat',
    'srlg',
    'srlg-cost',
    'srlg-value',
    'srr-queue',
    'ssh',
    'ssh-certificate',
    'ssh-publickey',
    'ssh_keydir',
    'sshportlist',
    'ssid',
    'ssid-enable',
    'ssid-profile',
    'ssl',
    'ssm',
    'stack-mac',
    'stack-mib',
    'stack-unit',
    'stale-route',
    'standard',
    'standby',
    'start-stop',
    'start-time',
    'startup-query-count',
    'startup-query-interval',
    'stat',
    'state',
    'state-refresh',
    'stateful-dot1x',
    'stateful-kerberos',
    'stateful-ntlm',
    'static',
    'static-group',
    'static-nat',
    'station-address',
    'station-port',
    'station-role',
    'statistics',
    'stbc',
    'stcapp',
    'sticky',
    'sticky-arp',
    'stop',
    'stop-only',
    'stop-record',
    'stopbits',
    'storm-control',
    'storm-control-profiles',
    'stp',
    'streaming',
    'street-address',
    'streetaddress',
    'stricthostkeycheck',
    'string',
    'strip',
    'sts-1',
    'stub',
    'sub-option',
    'sub-route-map',
    'subject-name',
    'submgmt',
    'subnet',
    'subnet-broadcast',
    'subnet-mask',
    'subnet-zero',
    'subnets',
    'subscribe-to',
    'subscribe-to-alert-group',
    'subscriber',
    'substat',
    'subtemplate',
    'subtract',
    'summary-address',
    'summary-lsa',
    'summary-only',
    'sun',
    'sun-rpc',
    'sunrpc',
    'super-user-password',
    'superpassword',
    'supplementary-service',
    'supplementary-services',
    'suppress-arp',
    'suppress-fib-pending',
    'suppressed',
    'suspect-rogue-conf-level',
    'svc',
    'svclc',
    'svp',
    'switch',
    'switch-cert',
    'switch-options',
    'switch-priority',
    'switch-profile',
    'switch-type',
    'switchback',
    'switching-mode',
    'switchname',
    'switchover-on-routing-crash',
    'switchport',
    'symmetric',
    'syn',
    'sync',
    'synchronization',
    'synchronous',
    'syscontact',
    'syslocation',
    'syslog',
    'syslogd',
    'sysopt',
    'system',
    'system-init',
    'system-max',
    'system-priority',
    'system-profile',
    'system-services',
    'system-shutdown',
    'systemname',
    'systemowner',
    'table-map',
    'tac_plus',
    'tacacs',
    'tacacs+',
    'tacacs-ds',
    'tacacs-server',
    'tacplus-server',
    'tacplusprimacctsecret',
    'tacplusprimaddr',
    'tacplusprimauthorsecret',
    'tacplusprimsecret',
    'tacplussecacctsecret',
    'tacplussecaddr',
    'tacplussecauthorsecret',
    'tacplussecsecret',
    'tacplususesub',
    'tag',
    'tag-switching',
    'tag-type',
    'tagged',
    'talk',
    'tap',
    'target',
    'target-host',
    'target-host-port',
    'targeted-broadcast',
    'targets',
    'task',
    'task execute',
    'task-scheduler',
    'taskgroup',
    'tb-vlan1',
    'tb-vlan2',
    'tcam',
    'tcp',
    'tcp-connect',
    'tcp-established',
    'tcp-flags',
    'tcp-initial',
    'tcp-inspection',
    'tcp-mss',
    'tcp-proxy-reassembly',
    'tcp-rst',
    'tcp-session',
    'tcp-udp',
    'tcs-load-balance',
    'te-metric',
    'teardown',
    'telnet',
    'telnet-server',
    'telnetclient',
    'template',
    'term',
    'terminal',
    'terminal-type',
    'termination',
    'test',
    'text',
    'tftp',
    'tftp-server',
    'tftp-server-list',
    'then',
    'threat-detection',
    'threat-visibility',
    'threshold',
    'through',
    'thu',
    'time',
    'time-exceeded',
    'time-format',
    'time-out',
    'time-range',
    'time-zone',
    'timed',
    'timeout',
    'timeouts',
    'timer',
    'timers',
    'timesource',
    'timestamp',
    'timestamp-reply',
    'timestamp-request',
    'timing',
    'tls-proxy',
    'tm-voq-collection',
    'to',
    'to-zone',
    'token',
    'tolerance',
    'tool',
    'top',
    'tos',
    'tos-overwrite',
    'trace',
    'traceoptions',
    'traceroute',
    'track',
    'tracked',
    'tracking-priority-increment',
    'traditional',
    'traffic-eng',
    'traffic-engineering',
    'traffic-index',
    'transceiver',
    'transceiver-type-check',
    'transfer-system',
    'transform-set',
    'translate',
    'translation',
    'translation-profile',
    'translation-rule',
    'transmit',
    'transmit-delay',
    'transparent-hw-flooding',
    'transport',
    'transport-method',
    'transport-mode',
    'trap-destinations',
    'trap-group',
    'trap-options',
    'trap-source',
    'trap-timeout',
    'traps',
    'trigger',
    'trimode',
    'true',
    'trunk',
    'trunk-threshold',
    'trust',
    'trusted',
    'trusted-key',
    'trustpoint',
    'trustpool',
    'tsid',
    'tsm-req-profile',
    'ttl',
    'ttl-exceeded',
    'ttl-threshold',
    'tty',
    'tue',
    'tunable-optic',
    'tunnel',
    'tunnel-group',
    'tunnel-group-list',
    'tunnel-id',
    'tunneled-node-address',
    'tx-queue',
    'txspeed',
    'type',
    'type-1',
    'type-2',
    'type-7',
    'uauth',
    'uc-tx-queue',
    'udf',
    'udld',
    'udp',
    'udp-jitter',
    'udplite',
    'uid',
    'unable',
    'unauthorized-device-profile',
    'unicast',
    'unicast-routing',
    'unique',
    'unit',
    'unnumbered',
    'unreachable',
    'unreachables',
    'untagged',
    'untrust',
    'untrust-screen',
    'update',
    'update-calendar',
    'update-source',
    'upgrade',
    'upgrade-profile',
    'uplink',
    'uplinkfast',
    'upstream',
    'upstream-start-threshold',
    'upto',
    'urg',
    'uri',
    'url',
    'url-list',
    'urpf',
    'urpf-logging',
    'use',
    'use-acl',
    'use-bia',
    'use-ipv4-acl',
    'use-ipv6-acl',
    'use-link-address',
    'use-vrf',
    'user',
    'user-identity',
    'user-message',
    'user-role',
    'user-statistics',
    'usergroup',
    'userinfo',
    'username',
    'username-prompt',
    'userpassphrase',
    'users',
    'using',
    'util-interval',
    'uucp',
    'uuid',
    'v1-only',
    'v1-rp-reachability',
    'v2',
    'v4',
    'v6',
    'vacant-message',
    'vacl',
    'vad',
    'valid-11a-40mhz-channel-pair',
    'valid-11a-80mhz-channel-group',
    'valid-11a-channel',
    'valid-11g-40mhz-channel-pair',
    'valid-11g-channel',
    'valid-and-protected-ssid',
    'valid-network-oui-profile',
    'validation-usage',
    'value',
    'vap-enable',
    'vdc',
    'ver',
    'verify',
    'verify-data',
    'version',
    'vfi',
    'via',
    'video',
    'view',
    'violate-action',
    'violation',
    'virtual',
    'virtual-address',
    'virtual-ap',
    'virtual-chassis',
    'virtual-reassembly',
    'virtual-router',
    'virtual-service',
    'virtual-switch',
    'virtual-template',
    'vlan',
    'vlan-group',
    'vlan-id',
    'vlan-id-list',
    'vlan-name',
    'vlan-policy',
    'vlan-tagging',
    'vlan-tags',
    'vlans',
    'vlt',
    'vlt-peer-lag',
    'vm-cpu',
    'vm-memory',
    'vmps',
    'vmtracer',
    'vocera',
    'voice',
    'voice-card',
    'voice-class',
    'voice-port',
    'voice-service',
    'voip',
    'voip-cac-profile',
    'vpc',
    'vpdn',
    'vpdn-group',
    'vpls',
    'vpn',
    'vpn-dialer',
    'vpn-filter',
    'vpn-group-policy',
    'vpn-idle-timeout',
    'vpn-monitor',
    'vpn-session-timeout',
    'vpn-simultaneous-logins',
    'vpn-tunnel-protocol',
    'vpnv4',
    'vpnv6',
    'vrf',
    'vrf-also',
    'vrf-export',
    'vrf-import',
    'vrf-table-label',
    'vrf-target',
    'vrrp',
    'vrrp-group',
    'vserver',
    'vstack',
    'vstp',
    'vti',
    'vtp',
    'vty',
    'vty-pool',
    'vxlan',
    'wait-for',
    'wait-start',
    'warnings',
    'warntime',
    'watch-list',
    'watchdog',
    'wavelength',
    'wccp',
    'web-cache',
    'web-https-port-443',
    'web-max-clients',
    'web-server',
    'webvpn',
    'wed',
    'weekday',
    'weekend',
    'weight',
    'weighting',
    'welcome-page',
    'white-list',
    'who',
    'whois',
    'wide',
    'wide-metric',
    'wide-metrics-only',
    'wideband',
    'wildcard-address',
    'window-size',
    'wins-server',
    'wired',
    'wired-ap-profile',
    'wired-containment',
    'wired-port-profile',
    'wired-to-wireless-roam',
    'wireless',
    'wireless-containment',
    'wirelessmodem',
    'wism',
    'wispr',
    'without-csd',
    'wlan',
    'wmm',
    'wms-general-profile',
    'wms-local-system-profile',
    'wpa-fast-handover',
    'wred',
    'wred-profile',
    'write-memory',
    'wrr',
    'wrr-queue',
    'wsma',
    'www',
    'x25',
    'x29',
    'x509',
    'xauth',
    'xconnect',
    'xdmcp',
    'xdr',
    'xlate',
    'xml-config',
    'xnm-clear-text',
    'xnm-ssl',
    'yellow',
    'zone',
    'zones'
}
